pub struct LintCommand {
pub file: Option<PathBuf>,
pub step_schema: Vec<(String, String)>,
pub remote: bool,
pub prepare: bool,
}Expand description
CLI command to lint a workflow file against the JSON schema.
Fields
file: Option<PathBuf>Path to the .storm workflow file to lint
step_schema: Vec<(String, String)>Additional step schemas to include in validation. Format: TYPE=PATH Where PATH can be a local file (e.g. MyStep=schema.json) Or a local git repository path using git-local scheme (e.g. MyStep=git-local:///path/to/repo?ref=main&file=schema.json)
remote: boolFetch the base schema from the remote server instead of using the local schema
prepare: boolDownload and store the server schemas locally for offline validation