pub enum RunCommands {
List {
owner: Option<String>,
name: Option<String>,
repo_url: Option<String>,
workflow_path: Option<String>,
created_after: Option<String>,
created_before: Option<String>,
status: Option<String>,
},
Get {
id: RunId,
},
Artifacts {
id: RunId,
},
Reports {
id: RunId,
},
Report {
id: RunId,
report_id: TestReportId,
},
Logs {
id: RunId,
step_name: String,
},
Watch {
id: RunId,
},
Enqueue {
workflow_name: String,
repo: String,
path: String,
git_ref: String,
input: Vec<String>,
tail: bool,
watch: bool,
},
Pending,
Approve {
run_id: RunId,
step_id: StepInstanceId,
input: Vec<String>,
},
Reject {
run_id: RunId,
step_id: StepInstanceId,
},
ApproveLink {
token: String,
},
}Variants
List
List workflow runs
Fields
Get
Get run details
Artifacts
List artifacts for a run
Reports
List test reports for a run
Report
Get a specific test report content
Logs
Stream logs for a specific step in a run
Watch
Stream real-time state transition events for a run
Enqueue
Enqueue a workflow from a git repository
Fields
Pending
List pending approvals/events
Approve
Approve a waiting step
Reject
Reject a waiting step
ApproveLink
Approve or reject a step using an encrypted token link