Commands

Enum Commands 

pub enum Commands {
    Run {
        file: PathBuf,
        input: Vec<String>,
        tail: bool,
        watch: bool,
    },
    Runs {
        command: RunCommands,
    },
    Webhooks {
        command: WebhookCommands,
    },
    Rules {
        command: RuleCommands,
    },
    Storage {
        command: StorageCommands,
    },
    Cron {
        command: CronCommands,
    },
    Lint(LintCommand),
    Schema {
        command: SchemaCommands,
    },
    Auth {
        command: AuthCommands,
    },
    Login {
        issuer: String,
        client_id: String,
    },
}
Available CLI subcommands.

Variants



Run

Run a local workflow DSL file (direct execution)

Fields

file: PathBuf

Path to the .storm file

input: Vec<String>

Input parameters in key=value format

tail: bool

Stream all logs from the workflow run until it completes

watch: bool

Stream real-time state transition events for a run until it completes



Runs

Manage workflow runs

Fields

command: RunCommands

Subcommands for runs



Webhooks

Manage webhooks

Fields

command: WebhookCommands

Subcommands for webhooks



Rules

Manage event rules

Fields

command: RuleCommands

Subcommands for event rules



Storage

Manage storage backends

Fields

command: StorageCommands

Subcommands for storage



Cron

Manage scheduled workflows (Cron)

Fields

command: CronCommands

Subcommands for cron workflows



Lint(LintCommand)

Lint a workflow file against the schema



Schema

Manage schemas

Fields

command: SchemaCommands

Subcommands for schemas



Auth

Authentication commands

Fields

command: AuthCommands

Subcommands for authentication



Login

Interactive browser-based login

Fields

issuer: String

The OIDC issuer URL.

client_id: String

The OIDC client ID.